@@ -1,4 +1,4 @@
-from macro import Window
+from macro.window import Window
 
 class Keyboard:
     def __init_(self, *, window: Window = None):
